IconNotFoundException class final
Thrown when an icon is not found in any provider.
- Inheritance
-
- Object
- IconifyException
- IconNotFoundException
Constructors
- IconNotFoundException({required IconifyName name, required String message, String? suggestion})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description. Always actionable. Never "an error occurred."
finalinherited
- name → IconifyName
-
The IconifyName that was requested but not found.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
Optional did-you-mean suggestion (e.g., 'lucide:settings' for 'lucide:setting').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited